/*
 *  Version: 1.0
 *
 *  The contents of this file are subject to the OpenVPMS License Version
 *  1.0 (the 'License'); you may not use this file except in compliance with
 *  the License. You may obtain a copy of the License at
 *  http://www.openvpms.org/license/
 *
 *  Software distributed under the License is distributed on an 'AS IS' basis,
 *  WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 *  for the specific language governing rights and limitations under the
 *  License.
 *
 *  Copyright 2006 (C) OpenVPMS Ltd. All Rights Reserved.
 *
 *  $Id$
 */

package org.openvpms.web.component.im.util;

import org.openvpms.component.business.domain.im.common.IMObject;
import org.openvpms.web.component.im.edit.IMObjectEditor;


/**
 * Listener for {@link IMObjectDeletor} events.
 *
 * @author <a href="mailto:support@openvpms.org">OpenVPMS Team</a>
 * @version $LastChangedDate: 2006-05-02 05:16:31Z $
 */
public interface IMObjectDeletionListener<T extends IMObject> {

    /**
     * Notifies that an object has been deleted.
     *
     * @param object the deleted object
     */
    void deleted(T object);

    /**
     * Notifies that an object has been deactivated.
     *
     * @param object the deactivated object
     */
    void deactivated(T object);

    /**
     * Notifies that an object has failed to be deleted.
     *
     * @param object the object that failed to be deleted
     * @param cause  the reason for the failure
     */
    void failed(T object, Throwable cause);


    /**
     * Notifies that an object has failed to be deleted.
     *
     * @param object the object that failed to be deleted
     * @param cause  the reason for the failure
     * @param editor the editor that performed the deletion
     */
    void failed(T object, Throwable cause, IMObjectEditor editor);

}
